#ifndef DAYPERIOD_H
#define DAYPERIOD_H
#include <QListWidgetItem>

class DayPeriod : public QObject
{
    Q_OBJECT

public:
    DayPeriod(int day);
    ~DayPeriod();
    void setInfo(QString &title, QString &condition, QString &temperature);
    void setIcon(QIcon* icon);
    QListWidgetItem* getItem(){
        return listItem;
    }

    int dayNum;
    void setLoading();

//public slots:
//    void requestFinished(QNetworkReply *reply);

private:
//    QNetworkAccessManager* manager;
    QListWidgetItem* listItem;
};

#endif // DAYPERIOD_H
